#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const core_1 = require("./core");
const core_2 = require("./core");
const fs = __importStar(require("fs"));
/**
 * Creates and configures the CLI program
 * @returns Configured Command instance
 */
function createProgram() {
    const program = new commander_1.Command();
    const logger = core_2.Logger.getInstance();
    program
        .name('files-to-prompt')
        .description('Generate a prompt from project files')
        .version('1.0.0')
        .argument('[paths...]', 'Paths to process')
        .option('-e, --extension <extensions...>', 'File extensions to include')
        .option('--include-hidden', 'Include files and folders starting with .')
        .option('--ignore-files-only', '--ignore option only ignores files')
        .option('--ignore-gitignore', 'Ignore .gitignore files and include all files')
        .option('--ignore <patterns...>', 'List of patterns to ignore')
        .option('-o, --output <file>', 'Output to a file instead of stdout')
        .option('-c, --cxml', "Output in XML-ish format suitable for Claude's long context window")
        .option('-m, --markdown', 'Output Markdown with fenced code blocks')
        .option('-n, --line-numbers', 'Add line numbers to the output')
        .option('--null, -0', 'Use NUL character as separator when reading from stdin')
        .option('--debug', 'Enable debug logging', false);
    return program;
}
/**
 * Reads paths from stdin
 * @param useNullSeparator Whether to use NUL character as separator
 * @returns Array of paths
 */
function readPathsFromStdin(useNullSeparator) {
    if (process.stdin.isTTY) {
        return [];
    }
    const stdinContent = fs.readFileSync(0, 'utf-8');
    if (useNullSeparator) {
        return stdinContent.split('\0').filter(Boolean);
    }
    return stdinContent.split(/\s+/).filter(Boolean);
}
/**
 * Main function to run the CLI application
 */
async function main() {
    const program = createProgram();
    const logger = core_2.Logger.getInstance();
    try {
        program.parse(process.argv);
        const options = program.opts();
        const paths = program.args;
        // Set debug mode
        if (options.debug) {
            process.env.DEBUG = 'true';
        }
        logger.info('Starting file processing...');
        // Read paths from stdin if no paths provided
        const allPaths = paths.length > 0 ? paths : readPathsFromStdin(options.null);
        const cliOptions = {
            extensions: options.extension,
            includeHidden: options.includeHidden === true,
            ignoreFilesOnly: options.ignoreFilesOnly === true,
            ignoreGitignore: options.ignoreGitignore === true,
            ignorePatterns: options.ignore,
            outputFile: options.output,
            claudeXml: options.cxml === true,
            markdown: options.markdown === true,
            lineNumbers: options.lineNumbers === true,
            useNullSeparator: options.null === true,
        };
        const output = await (0, core_1.processPaths)(allPaths, cliOptions);
        if (options.output) {
            fs.writeFileSync(options.output, output);
        }
        else {
            console.log(output);
        }
        logger.info('File processing completed successfully');
    }
    catch (error) {
        if (error instanceof core_1.FileProcessingError) {
            logger.error('File processing error:', error);
            process.exit(1);
        }
        else {
            logger.error('Unexpected error:', error);
            process.exit(1);
        }
    }
}
// Run the CLI
main().catch(error => {
    const logger = core_2.Logger.getInstance();
    logger.error('Fatal error:', error);
    process.exit(1);
});
