import { Options } from './types';
/**
 * Custom error class for file processing errors
 */
export declare class FileProcessingError extends Error {
    readonly cause?: Error | undefined;
    constructor(message: string, cause?: Error | undefined);
}
/**
 * Logger class for consistent logging throughout the application
 */
export declare class Logger {
    private static instance;
    private isDebug;
    private constructor();
    static getInstance(): Logger;
    debug(message: string): void;
    info(message: string): void;
    error(message: string, error?: Error): void;
}
/**
 * Adds line numbers to the content of a file
 * @param content - The content of the file
 * @returns The content with line numbers added
 */
export declare function addLineNumbers(content: string): string;
/**
 * Processes a path and returns its content
 */
export declare function processPath(filePath: string, options: Options, writer: (content: string) => void): Promise<void>;
/**
 * Processes multiple paths and returns the combined output
 */
export declare function processPaths(paths: string[], options: Options): Promise<string>;
